var _scene;

var BabylonModel = function(canvas) {
    this.engine = new BABYLON.Engine(canvas, true);

    // Resize window event
    var _this = this;
	
	//remove manifest request
	this.engine.enableOfflineSupport = false;

    window.addEventListener("resize", function() {
        _this.engine.resize();
    });

    var loadingScreen = new MyLoadingScreen("I'm loading!!");
    //Set the loading screen in the engine to replace the default one
    this.engine.loadingScreen = loadingScreen;

    // Load scene
    BABYLON.SceneLoader.Load("assets/", "modelName.babylon", this.engine, function(scene) {
		window.scene = scene;
        _this.scene = scene;
        _scene = scene;
        _this.initScene();

        scene.executeWhenReady(function() {
            _this.engine.runRenderLoop(function () {
                _this.scene.render();
            });
        });

    });
};


var bonesAnimation = new Array();
var arcCamera;
BabylonModel.prototype.initScene = function() {
    this.scene.clearColor = new BABYLON.Color4(0.95,0.95,0.95,1);

    arcCamera = new BABYLON.ArcRotateCamera("ArcRotateCamera", 10, 0, 100, new BABYLON.Vector3(0, 0, 0), this.scene);
    arcCamera.setPosition(this.scene.activeCamera.position);
    //arcCamera.lowerBetaLimit = 0.3;
    //arcCamera.upperBetaLimit = (Math.PI / 2) * 1;
    arcCamera.lowerRadiusLimit = 13;
    arcCamera.upperRadiusLimit = 500;
	arcCamera.radius=370; 
    arcCamera.attachControl(this.engine.getRenderingCanvas(),true);
    this.scene.activeCamera = arcCamera;

//    this.initMaterial();

    this.initLights();
	
	this.initAnimations();
	this.initButtons();


};

BabylonModel.prototype.initLights = function() {

	this.scene.lights = [];
	var light = new BABYLON.DirectionalLight( "dir01", new BABYLON.Vector3( -10, -20, -10 ), this.scene );
	light.position = new BABYLON.Vector3( 20, 40, 20 );
	light.intensity = 0.8;


	var light2 = new BABYLON.DirectionalLight( "dir02", new BABYLON.Vector3( 10, -20, 10 ), this.scene );
	light2.position = new BABYLON.Vector3( -20, -40, -20 );
	light2.intensity = 0.5;

	var light3 = new BABYLON.HemisphericLight( "Hemi1", new BABYLON.Vector3( 0, -1, 0 ), this.scene );
	light3.intensity = 0.8;
};

BabylonModel.prototype.initMaterial = function() {
    _scene = this.scene;

    this.scene.meshes.forEach(function (mesh) {

        if (mesh.material) {
            if (mesh.material.name == "white") {
                mesh.material.backFaceCulling = false;
                mesh.material.diffuseColor = new BABYLON.Color3(0.85,0.85,0.85);
            }
        }
    });

};

BabylonModel.prototype.initAnimations = function() {
    var _this = this;

    this.scene.meshes.forEach(function (mesh) {
        bonesAnimation.push(mesh);
        _this.scene.stopAnimation(mesh);

    });
	for (i=0; i<bonesAnimation.length; i++) {
        this.scene.beginAnimation(bonesAnimation[i], 0, 1, false);
    } 
};

BabylonModel.prototype.initButtons = function() {
	
	animationButtons = $('.animation-button');
	
	var step = 0;
	animationButtons.off('click').on('click', (function () {
				return function () {
					var _self = $(this);
					var state = _self.data('state');
					changeAnimationState(state);
				}
			})())
	
	changeAnimationState = function(state) {
		_scene = this.scene;
		if (state ==="next") {
			if (step ==2) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 120, 150, false, 1);
				}
				step ++;
			}
			if (step ==1) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 60, 120, false, 1);
				}
				step ++;
			}
			if (step ==0) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 0, 60, false, 1);
				}
				step ++;
			}
		}
		if (state === "previous" ) {
			if (step==1) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 200, 300, false, 1);
				}
				step --;
			}
			if (step==2) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 120, 200, false, 1);
				}
				step --;
			}
			
			if (step==3) {
				for (i=0; i<bonesAnimation.length; i++) {
					_scene.beginAnimation(bonesAnimation[i], 9, 200, false, 1);
				}
				step --;
			}
			
		}
	}
};

getTexture = function (name) {
    var a = -1;
    var b = -1;
    for ( i = 0; i < _scene.meshes.length; i ++ ) {
        if (typeof _scene.meshes[i].material != "undefined" && _scene.meshes[i].material != null ) {
			if (typeof _scene.meshes[i].material.name != "undefined" ) {
				if ( _scene.meshes[i].material.name == name ) {
					a = i;
				}
			}
            if (typeof(_scene.meshes[i].material.subMaterials) != 'undefined') {
                for (var j = 0; j < _scene.meshes[i].material.subMaterials.length; j++) {
                    if ( _scene.meshes[i].material.subMaterials[j].name==name) {
                        b=j;
						a=i;
                    }
                }
            }
        }
    }
    if (a!=-1) {
        if (b != -1) {
            console.log( "Texture for " + name + " is:" );
            console.log( a + "." + b );
        } else {
            console.log( "Texture for " + name + " is:" );
            console.log( a );
        }
    } else {
        console.log ("No texture found for " + name);
        console.log ("Check the name and try again");
    }

};

function MyLoadingScreen(text) {
  //init the loader
  this.loadingUIText = text;
}
MyLoadingScreen.prototype.displayLoadingUI = function() {
  //alert(this.loadingUIText);
  return;
};
MyLoadingScreen.prototype.hideLoadingUI = function() {
  //alert("Loaded!");
  return;
};
